# Solar Focus - Virtual Data

This library includes set of scripts for creating virtual data do be displayed in SolarFocus.

## Installation
Please make sure you have scripts requirements installed in your local environment:

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install the requirements.

```bash
pip install -r requirements.txt
```

## Usage

For creating valid virtual data follow these steps:
1. fill the required form in SolarFoucs in order to generate entry point script and calculation script template.
2. download it (click on "Generate Offline")
3. fill generated user_calculation script.
4. Validate the script by running the script in debug mode (using --debug)
5. Upload the script to Solar Focus

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.